[gtk/wip/nielsdg/g-declare-interface] buildable: Use G_DECLARE_INTERFACE



commit ff79be372696d55fd67f3ca7815346fd2e597947
Author: Niels De Graef <nielsdegraef gmail com>
Date:   Sat Apr 4 11:21:40 2020 +0200

    buildable: Use G_DECLARE_INTERFACE

 docs/reference/gtk/gtk4-sections.txt |  2 +-
 gtk/gtk-autocleanups.h               |  1 -
 gtk/gtkactionbar.c                   |  6 +++---
 gtk/gtkassistant.c                   |  6 +++---
 gtk/gtkbuildable.c                   | 21 ++++++++++-----------
 gtk/gtkbuildable.h                   | 19 +++++--------------
 gtk/gtkbuilder.c                     |  4 ++--
 gtk/gtkcellarea.c                    |  8 ++++----
 gtk/gtkcellview.c                    |  6 +++---
 gtk/gtkcenterbox.c                   |  6 +++---
 gtk/gtkcombobox.c                    |  6 +++---
 gtk/gtkcomboboxtext.c                |  6 +++---
 gtk/gtkconstraintlayout.c            |  4 ++--
 gtk/gtkcontainer.c                   |  6 +++---
 gtk/gtkdialog.c                      |  6 +++---
 gtk/gtkentrycompletion.c             |  4 ++--
 gtk/gtkexpander.c                    |  6 +++---
 gtk/gtkfilefilter.c                  |  4 ++--
 gtk/gtkfontchooserdialog.c           |  6 +++---
 gtk/gtkframe.c                       |  6 +++---
 gtk/gtkheaderbar.c                   |  6 +++---
 gtk/gtkiconview.c                    |  6 +++---
 gtk/gtkinfobar.c                     |  6 +++---
 gtk/gtklabel.c                       |  6 +++---
 gtk/gtklevelbar.c                    |  4 ++--
 gtk/gtklistbox.c                     |  6 +++---
 gtk/gtkliststore.c                   |  4 ++--
 gtk/gtknotebook.c                    |  6 +++---
 gtk/gtkoverlay.c                     |  6 +++---
 gtk/gtkprintunixdialog.c             |  6 +++---
 gtk/gtkscale.c                       |  6 +++---
 gtk/gtkshortcutcontroller.c          |  2 +-
 gtk/gtksizegroup.c                   |  4 ++--
 gtk/gtkstack.c                       |  4 ++--
 gtk/gtktexttagtable.c                |  4 ++--
 gtk/gtktreestore.c                   |  4 ++--
 gtk/gtktreeview.c                    |  6 +++---
 gtk/gtktreeviewcolumn.c              |  4 ++--
 gtk/gtkwidget.c                      |  6 +++---
 gtk/gtkwindow.c                      |  6 +++---
 40 files changed, 112 insertions(+), 123 deletions(-)
---
diff --git a/docs/reference/gtk/gtk4-sections.txt b/docs/reference/gtk/gtk4-sections.txt
index e06c903b38..c94541242a 100644
--- a/docs/reference/gtk/gtk4-sections.txt
+++ b/docs/reference/gtk/gtk4-sections.txt
@@ -423,7 +423,7 @@ gtk_single_selection_get_type
 <SECTION>
 <FILE>gtkbuildable</FILE>
 GtkBuildable
-GtkBuildableIface
+GtkBuildableInterface
 gtk_buildable_set_name
 gtk_buildable_get_name
 gtk_buildable_add_child
diff --git a/gtk/gtk-autocleanups.h b/gtk/gtk-autocleanups.h
index 0309ac9481..63eab9aa3d 100644
--- a/gtk/gtk-autocleanups.h
+++ b/gtk/gtk-autocleanups.h
@@ -32,7 +32,6 @@ G_DEFINE_AUTOPTR_CLEANUP_FUNC(GtkApplicationWindow, g_object_unref)
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(GtkAspectFrame, g_object_unref)
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(GtkAssistant, g_object_unref)
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(GtkBox, g_object_unref)
-G_DEFINE_AUTOPTR_CLEANUP_FUNC(GtkBuildable, g_object_unref)
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(GtkBuilder, g_object_unref)
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(GtkButton, g_object_unref)
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(GtkCalendar, g_object_unref)
diff --git a/gtk/gtkactionbar.c b/gtk/gtkactionbar.c
index ad468a0705..3c663a879e 100644
--- a/gtk/gtkactionbar.c
+++ b/gtk/gtkactionbar.c
@@ -78,7 +78,7 @@ enum {
 };
 static GParamSpec *props[LAST_PROP] = { NULL, };
 
-static void gtk_action_bar_buildable_interface_init (GtkBuildableIface *iface);
+static void gtk_action_bar_buildable_interface_init (GtkBuildableInterface *iface);
 
 G_DEFINE_TYPE_WITH_CODE (GtkActionBar, gtk_action_bar, GTK_TYPE_CONTAINER,
                          G_IMPLEMENT_INTERFACE (GTK_TYPE_BUILDABLE,
@@ -253,7 +253,7 @@ gtk_action_bar_init (GtkActionBar *self)
   gtk_container_add (GTK_CONTAINER (self->revealer), self->center_box);
 }
 
-static GtkBuildableIface *parent_buildable_iface;
+static GtkBuildableInterface *parent_buildable_iface;
 
 static void
 gtk_action_bar_buildable_add_child (GtkBuildable *buildable,
@@ -274,7 +274,7 @@ gtk_action_bar_buildable_add_child (GtkBuildable *buildable,
 }
 
 static void
-gtk_action_bar_buildable_interface_init (GtkBuildableIface *iface)
+gtk_action_bar_buildable_interface_init (GtkBuildableInterface *iface)
 {
   parent_buildable_iface = g_type_interface_peek_parent (iface);
   iface->add_child = gtk_action_bar_buildable_add_child;
diff --git a/gtk/gtkassistant.c b/gtk/gtkassistant.c
index b0b46c1dd2..eb0a0a847a 100644
--- a/gtk/gtkassistant.c
+++ b/gtk/gtkassistant.c
@@ -177,7 +177,7 @@ static void     gtk_assistant_page_get_property  (GObject           *object,
                                                   GValue            *value,
                                                   GParamSpec        *pspec);
 
-static void     gtk_assistant_buildable_interface_init   (GtkBuildableIface  *iface);
+static void     gtk_assistant_buildable_interface_init   (GtkBuildableInterface  *iface);
 static void     gtk_assistant_buildable_add_child        (GtkBuildable       *buildable,
                                                           GtkBuilder         *builder,
                                                           GObject            *child,
@@ -2318,10 +2318,10 @@ _gtk_assistant_accessible_init (GtkAssistantAccessible *self)
 
 /* buildable implementation */
 
-static GtkBuildableIface *parent_buildable_iface;
+static GtkBuildableInterface *parent_buildable_iface;
 
 static void
-gtk_assistant_buildable_interface_init (GtkBuildableIface *iface)
+gtk_assistant_buildable_interface_init (GtkBuildableInterface *iface)
 {
   parent_buildable_iface = g_type_interface_peek_parent (iface);
   iface->custom_tag_start = gtk_assistant_buildable_custom_tag_start;
diff --git a/gtk/gtkbuildable.c b/gtk/gtkbuildable.c
index 7211c3b300..79a671a12f 100644
--- a/gtk/gtkbuildable.c
+++ b/gtk/gtkbuildable.c
@@ -40,7 +40,6 @@
 #include "gtkintl.h"
 
 
-typedef GtkBuildableIface GtkBuildableInterface;
 G_DEFINE_INTERFACE (GtkBuildable, gtk_buildable, G_TYPE_OBJECT)
 
 static void
@@ -59,7 +58,7 @@ void
 gtk_buildable_set_name (GtkBuildable *buildable,
                         const gchar  *name)
 {
-  GtkBuildableIface *iface;
+  GtkBuildableInterface *iface;
 
   g_return_if_fail (GTK_IS_BUILDABLE (buildable));
   g_return_if_fail (name != NULL);
@@ -90,7 +89,7 @@ gtk_buildable_set_name (GtkBuildable *buildable,
 const gchar *
 gtk_buildable_get_name (GtkBuildable *buildable)
 {
-  GtkBuildableIface *iface;
+  GtkBuildableInterface *iface;
 
   g_return_val_if_fail (GTK_IS_BUILDABLE (buildable), NULL);
 
@@ -119,7 +118,7 @@ gtk_buildable_add_child (GtkBuildable *buildable,
                         GObject      *child,
                         const gchar  *type)
 {
-  GtkBuildableIface *iface;
+  GtkBuildableInterface *iface;
 
   g_return_if_fail (GTK_IS_BUILDABLE (buildable));
   g_return_if_fail (GTK_IS_BUILDER (builder));
@@ -145,7 +144,7 @@ gtk_buildable_set_buildable_property (GtkBuildable *buildable,
                                      const gchar  *name,
                                      const GValue *value)
 {
-  GtkBuildableIface *iface;
+  GtkBuildableInterface *iface;
 
   g_return_if_fail (GTK_IS_BUILDABLE (buildable));
   g_return_if_fail (GTK_IS_BUILDER (builder));
@@ -174,7 +173,7 @@ void
 gtk_buildable_parser_finished (GtkBuildable *buildable,
                               GtkBuilder   *builder)
 {
-  GtkBuildableIface *iface;
+  GtkBuildableInterface *iface;
 
   g_return_if_fail (GTK_IS_BUILDABLE (buildable));
   g_return_if_fail (GTK_IS_BUILDER (builder));
@@ -202,7 +201,7 @@ gtk_buildable_construct_child (GtkBuildable *buildable,
                                GtkBuilder   *builder,
                                const gchar  *name)
 {
-  GtkBuildableIface *iface;
+  GtkBuildableInterface *iface;
 
   g_return_val_if_fail (GTK_IS_BUILDABLE (buildable), NULL);
   g_return_val_if_fail (GTK_IS_BUILDER (builder), NULL);
@@ -237,7 +236,7 @@ gtk_buildable_custom_tag_start (GtkBuildable       *buildable,
                                 GtkBuildableParser *parser,
                                 gpointer           *data)
 {
-  GtkBuildableIface *iface;
+  GtkBuildableInterface *iface;
 
   g_return_val_if_fail (GTK_IS_BUILDABLE (buildable), FALSE);
   g_return_val_if_fail (GTK_IS_BUILDER (builder), FALSE);
@@ -268,7 +267,7 @@ gtk_buildable_custom_tag_end (GtkBuildable  *buildable,
                               const gchar   *tagname,
                               gpointer       data)
 {
-  GtkBuildableIface *iface;
+  GtkBuildableInterface *iface;
 
   g_return_if_fail (GTK_IS_BUILDABLE (buildable));
   g_return_if_fail (GTK_IS_BUILDER (builder));
@@ -297,7 +296,7 @@ gtk_buildable_custom_finished (GtkBuildable  *buildable,
                               const gchar   *tagname,
                               gpointer       data)
 {
-  GtkBuildableIface *iface;
+  GtkBuildableInterface *iface;
 
   g_return_if_fail (GTK_IS_BUILDABLE (buildable));
   g_return_if_fail (GTK_IS_BUILDER (builder));
@@ -322,7 +321,7 @@ gtk_buildable_get_internal_child (GtkBuildable *buildable,
                                   GtkBuilder   *builder,
                                   const gchar  *childname)
 {
-  GtkBuildableIface *iface;
+  GtkBuildableInterface *iface;
 
   g_return_val_if_fail (GTK_IS_BUILDABLE (buildable), NULL);
   g_return_val_if_fail (GTK_IS_BUILDER (builder), NULL);
diff --git a/gtk/gtkbuilder.c b/gtk/gtkbuilder.c
index a4351bade1..5a4cff70f8 100644
--- a/gtk/gtkbuilder.c
+++ b/gtk/gtkbuilder.c
@@ -690,7 +690,7 @@ _gtk_builder_construct (GtkBuilder  *builder,
   ObjectProperties *parameters, *construct_parameters;
   GObject *obj;
   int i;
-  GtkBuildableIface *iface;
+  GtkBuildableInterface *iface;
   gboolean custom_set_property;
   GtkBuildable *buildable;
   GParamFlags param_filter_flags;
@@ -850,7 +850,7 @@ _gtk_builder_apply_properties (GtkBuilder  *builder,
                                GError     **error)
 {
   ObjectProperties *parameters;
-  GtkBuildableIface *iface;
+  GtkBuildableInterface *iface;
   GtkBuildable *buildable;
   gboolean custom_set_property;
   gint i;
diff --git a/gtk/gtkcellarea.c b/gtk/gtkcellarea.c
index a4351d14c3..2aa45a9c6f 100644
--- a/gtk/gtkcellarea.c
+++ b/gtk/gtkcellarea.c
@@ -463,8 +463,8 @@ static void      gtk_cell_area_reorder                       (GtkCellLayout
 static GList    *gtk_cell_area_get_cells                     (GtkCellLayout         *cell_layout);
 static GtkCellArea *gtk_cell_area_get_area                   (GtkCellLayout         *cell_layout);
 
-/* GtkBuildableIface */
-static void      gtk_cell_area_buildable_init                (GtkBuildableIface     *iface);
+/* GtkBuildableInterface */
+static void      gtk_cell_area_buildable_init                (GtkBuildableInterface     *iface);
 static void      gtk_cell_area_buildable_custom_tag_end      (GtkBuildable          *buildable,
                                                               GtkBuilder            *builder,
                                                               GObject               *child,
@@ -1562,10 +1562,10 @@ gtk_cell_area_get_area (GtkCellLayout *cell_layout)
 }
 
 /*************************************************************
- *                   GtkBuildableIface                       *
+ *                   GtkBuildableInterface                   *
  *************************************************************/
 static void
-gtk_cell_area_buildable_init (GtkBuildableIface *iface)
+gtk_cell_area_buildable_init (GtkBuildableInterface *iface)
 {
   iface->add_child = _gtk_cell_layout_buildable_add_child;
   iface->custom_tag_start = _gtk_cell_layout_buildable_custom_tag_start;
diff --git a/gtk/gtkcellview.c b/gtk/gtkcellview.c
index 12132c2944..6946f4e564 100644
--- a/gtk/gtkcellview.c
+++ b/gtk/gtkcellview.c
@@ -83,7 +83,7 @@ static GtkCellArea *gtk_cell_view_cell_layout_get_area         (GtkCellLayout
 
 
 /* buildable */
-static void        gtk_cell_view_buildable_init             (GtkBuildableIface  *iface);
+static void        gtk_cell_view_buildable_init             (GtkBuildableInterface  *iface);
 static gboolean    gtk_cell_view_buildable_custom_tag_start (GtkBuildable       *buildable,
                                                              GtkBuilder         *builder,
                                                              GObject            *child,
@@ -142,7 +142,7 @@ struct _GtkCellViewPrivate
   guint                fit_model      : 1;
 };
 
-static GtkBuildableIface *parent_buildable_iface;
+static GtkBuildableInterface *parent_buildable_iface;
 
 enum
 {
@@ -295,7 +295,7 @@ gtk_cell_view_buildable_add_child (GtkBuildable *buildable,
 }
 
 static void
-gtk_cell_view_buildable_init (GtkBuildableIface *iface)
+gtk_cell_view_buildable_init (GtkBuildableInterface *iface)
 {
   parent_buildable_iface = g_type_interface_peek_parent (iface);
   iface->add_child = gtk_cell_view_buildable_add_child;
diff --git a/gtk/gtkcenterbox.c b/gtk/gtkcenterbox.c
index 8bd0a7fda0..d575c5c829 100644
--- a/gtk/gtkcenterbox.c
+++ b/gtk/gtkcenterbox.c
@@ -86,9 +86,9 @@ enum {
   PROP_ORIENTATION
 };
 
-static GtkBuildableIface *parent_buildable_iface;
+static GtkBuildableInterface *parent_buildable_iface;
 
-static void gtk_center_box_buildable_init (GtkBuildableIface *iface);
+static void gtk_center_box_buildable_init (GtkBuildableInterface *iface);
 
 G_DEFINE_TYPE_WITH_CODE (GtkCenterBox, gtk_center_box, GTK_TYPE_WIDGET,
                          G_IMPLEMENT_INTERFACE (GTK_TYPE_ORIENTABLE, NULL)
@@ -111,7 +111,7 @@ gtk_center_box_buildable_add_child (GtkBuildable  *buildable,
 }
 
 static void
-gtk_center_box_buildable_init (GtkBuildableIface *iface)
+gtk_center_box_buildable_init (GtkBuildableInterface *iface)
 {
   parent_buildable_iface = g_type_interface_peek_parent (iface);
 
diff --git a/gtk/gtkcombobox.c b/gtk/gtkcombobox.c
index f270d55d3d..56912589c8 100644
--- a/gtk/gtkcombobox.c
+++ b/gtk/gtkcombobox.c
@@ -293,9 +293,9 @@ static gchar   *gtk_combo_box_format_entry_text              (GtkComboBox     *c
                                                               const gchar     *path);
 
 /* GtkBuildable method implementation */
-static GtkBuildableIface *parent_buildable_iface;
+static GtkBuildableInterface *parent_buildable_iface;
 
-static void     gtk_combo_box_buildable_init                 (GtkBuildableIface  *iface);
+static void     gtk_combo_box_buildable_init                 (GtkBuildableInterface  *iface);
 static void     gtk_combo_box_buildable_add_child            (GtkBuildable       *buildable,
                                                               GtkBuilder         *builder,
                                                               GObject            *child,
@@ -807,7 +807,7 @@ gtk_combo_box_class_init (GtkComboBoxClass *klass)
 }
 
 static void
-gtk_combo_box_buildable_init (GtkBuildableIface *iface)
+gtk_combo_box_buildable_init (GtkBuildableInterface *iface)
 {
   parent_buildable_iface = g_type_interface_peek_parent (iface);
   iface->add_child = gtk_combo_box_buildable_add_child;
diff --git a/gtk/gtkcomboboxtext.c b/gtk/gtkcomboboxtext.c
index bbfd426430..5bdfe60d1f 100644
--- a/gtk/gtkcomboboxtext.c
+++ b/gtk/gtkcomboboxtext.c
@@ -99,7 +99,7 @@ struct _GtkComboBoxTextClass
 };
 
 
-static void     gtk_combo_box_text_buildable_interface_init   (GtkBuildableIface  *iface);
+static void     gtk_combo_box_text_buildable_interface_init   (GtkBuildableInterface  *iface);
 static gboolean gtk_combo_box_text_buildable_custom_tag_start (GtkBuildable       *buildable,
                                                                GtkBuilder         *builder,
                                                                GObject            *child,
@@ -114,7 +114,7 @@ static void     gtk_combo_box_text_buildable_custom_finished  (GtkBuildable
                                                                gpointer            user_data);
 
 
-static GtkBuildableIface *buildable_parent_iface = NULL;
+static GtkBuildableInterface *buildable_parent_iface = NULL;
 
 G_DEFINE_TYPE_WITH_CODE (GtkComboBoxText, gtk_combo_box_text, GTK_TYPE_COMBO_BOX,
                         G_IMPLEMENT_INTERFACE (GTK_TYPE_BUILDABLE,
@@ -162,7 +162,7 @@ gtk_combo_box_text_class_init (GtkComboBoxTextClass *klass)
 }
 
 static void
-gtk_combo_box_text_buildable_interface_init (GtkBuildableIface *iface)
+gtk_combo_box_text_buildable_interface_init (GtkBuildableInterface *iface)
 {
   buildable_parent_iface = g_type_interface_peek_parent (iface);
 
diff --git a/gtk/gtkconstraintlayout.c b/gtk/gtkconstraintlayout.c
index 7f012da0c6..5b13b28880 100644
--- a/gtk/gtkconstraintlayout.c
+++ b/gtk/gtkconstraintlayout.c
@@ -527,7 +527,7 @@ gtk_constraint_layout_child_init (GtkConstraintLayoutChild *self)
                            (GDestroyNotify) gtk_constraint_variable_unref);
 }
 
-static void gtk_buildable_interface_init (GtkBuildableIface *iface);
+static void gtk_buildable_interface_init (GtkBuildableInterface *iface);
 
 G_DEFINE_TYPE_WITH_CODE (GtkConstraintLayout, gtk_constraint_layout, GTK_TYPE_LAYOUT_MANAGER,
                          G_IMPLEMENT_INTERFACE (GTK_TYPE_BUILDABLE, gtk_buildable_interface_init))
@@ -1675,7 +1675,7 @@ gtk_constraint_layout_custom_finished (GtkBuildable *buildable,
 }
 
 static void
-gtk_buildable_interface_init (GtkBuildableIface *iface)
+gtk_buildable_interface_init (GtkBuildableInterface *iface)
 {
   iface->custom_tag_start = gtk_constraint_layout_custom_tag_start;
   iface->custom_tag_end = gtk_constraint_layout_custom_tag_end;
diff --git a/gtk/gtkcontainer.c b/gtk/gtkcontainer.c
index 7d74e4f069..aa8b75d1f7 100644
--- a/gtk/gtkcontainer.c
+++ b/gtk/gtkcontainer.c
@@ -116,8 +116,8 @@ static void     gtk_container_children_callback    (GtkWidget         *widget,
 static GtkSizeRequestMode gtk_container_get_request_mode (GtkWidget   *widget);
 
 /* GtkBuildable */
-static void gtk_container_buildable_init           (GtkBuildableIface *iface);
-static GtkBuildableIface    *parent_buildable_iface;
+static void gtk_container_buildable_init           (GtkBuildableInterface *iface);
+static GtkBuildableInterface    *parent_buildable_iface;
 
 static GQuark                vadjustment_key_id;
 static GQuark                hadjustment_key_id;
@@ -190,7 +190,7 @@ gtk_container_buildable_add_child (GtkBuildable  *buildable,
 }
 
 static void
-gtk_container_buildable_init (GtkBuildableIface *iface)
+gtk_container_buildable_init (GtkBuildableInterface *iface)
 {
   parent_buildable_iface = g_type_interface_peek_parent (iface);
   iface->add_child = gtk_container_buildable_add_child;
diff --git a/gtk/gtkdialog.c b/gtk/gtkdialog.c
index a2cc9e15ef..d3cf9b2bdc 100644
--- a/gtk/gtkdialog.c
+++ b/gtk/gtkdialog.c
@@ -197,7 +197,7 @@ static void      gtk_dialog_close                (GtkDialog    *dialog);
 static ResponseData * get_response_data          (GtkWidget    *widget,
                                                   gboolean      create);
 
-static void     gtk_dialog_buildable_interface_init   (GtkBuildableIface  *iface);
+static void     gtk_dialog_buildable_interface_init   (GtkBuildableInterface  *iface);
 static gboolean gtk_dialog_buildable_custom_tag_start (GtkBuildable       *buildable,
                                                        GtkBuilder         *builder,
                                                        GObject            *child,
@@ -589,10 +589,10 @@ gtk_dialog_init (GtkDialog *dialog)
   gtk_widget_init_template (GTK_WIDGET (dialog));
 }
 
-static GtkBuildableIface *parent_buildable_iface;
+static GtkBuildableInterface *parent_buildable_iface;
 
 static void
-gtk_dialog_buildable_interface_init (GtkBuildableIface *iface)
+gtk_dialog_buildable_interface_init (GtkBuildableInterface *iface)
 {
   parent_buildable_iface = g_type_interface_peek_parent (iface);
   iface->custom_tag_start = gtk_dialog_buildable_custom_tag_start;
diff --git a/gtk/gtkentrycompletion.c b/gtk/gtkentrycompletion.c
index ad0b36d634..9fb7793e21 100644
--- a/gtk/gtkentrycompletion.c
+++ b/gtk/gtkentrycompletion.c
@@ -186,7 +186,7 @@ static GParamSpec *entry_completion_props[NUM_PROPERTIES] = { NULL, };
 static guint entry_completion_signals[LAST_SIGNAL] = { 0 };
 
 /* GtkBuildable */
-static void     gtk_entry_completion_buildable_init      (GtkBuildableIface  *iface);
+static void     gtk_entry_completion_buildable_init      (GtkBuildableInterface  *iface);
 
 G_DEFINE_TYPE_WITH_CODE (GtkEntryCompletion, gtk_entry_completion, G_TYPE_OBJECT,
                          G_ADD_PRIVATE (GtkEntryCompletion)
@@ -457,7 +457,7 @@ gtk_entry_completion_buildable_custom_tag_end (GtkBuildable *buildable,
 }
 
 static void
-gtk_entry_completion_buildable_init (GtkBuildableIface *iface)
+gtk_entry_completion_buildable_init (GtkBuildableInterface *iface)
 {
   iface->add_child = _gtk_cell_layout_buildable_add_child;
   iface->custom_tag_start = _gtk_cell_layout_buildable_custom_tag_start;
diff --git a/gtk/gtkexpander.c b/gtk/gtkexpander.c
index dbe31e68e0..a2d1e8e341 100644
--- a/gtk/gtkexpander.c
+++ b/gtk/gtkexpander.c
@@ -202,7 +202,7 @@ static void gtk_expander_activate (GtkExpander *expander);
 
 
 /* GtkBuildable */
-static void gtk_expander_buildable_init           (GtkBuildableIface *iface);
+static void gtk_expander_buildable_init           (GtkBuildableInterface *iface);
 static void gtk_expander_buildable_add_child      (GtkBuildable *buildable,
                                                    GtkBuilder   *builder,
                                                    GObject      *child,
@@ -425,7 +425,7 @@ gtk_expander_init (GtkExpander *expander)
   gtk_widget_add_controller (GTK_WIDGET (priv->title_widget), GTK_EVENT_CONTROLLER (gesture));
 }
 
-static GtkBuildableIface *parent_buildable_iface;
+static GtkBuildableInterface *parent_buildable_iface;
 
 static void
 gtk_expander_buildable_add_child (GtkBuildable  *buildable,
@@ -440,7 +440,7 @@ gtk_expander_buildable_add_child (GtkBuildable  *buildable,
 }
 
 static void
-gtk_expander_buildable_init (GtkBuildableIface *iface)
+gtk_expander_buildable_init (GtkBuildableInterface *iface)
 {
   parent_buildable_iface = g_type_interface_peek_parent (iface);
 
diff --git a/gtk/gtkfilefilter.c b/gtk/gtkfilefilter.c
index 33ad641065..9b8d95993b 100644
--- a/gtk/gtkfilefilter.c
+++ b/gtk/gtkfilefilter.c
@@ -142,7 +142,7 @@ static void gtk_file_filter_get_property (GObject            *object,
 static void gtk_file_filter_finalize   (GObject            *object);
 
 
-static void         gtk_file_filter_buildable_init             (GtkBuildableIface  *iface);
+static void         gtk_file_filter_buildable_init             (GtkBuildableInterface *iface);
 
 static gboolean     gtk_file_filter_buildable_custom_tag_start (GtkBuildable       *buildable,
                                                                 GtkBuilder         *builder,
@@ -271,7 +271,7 @@ gtk_file_filter_finalize (GObject  *object)
  * GtkBuildable implementation
  */
 static void
-gtk_file_filter_buildable_init (GtkBuildableIface *iface)
+gtk_file_filter_buildable_init (GtkBuildableInterface *iface)
 {
   iface->custom_tag_start = gtk_file_filter_buildable_custom_tag_start;
   iface->custom_tag_end = gtk_file_filter_buildable_custom_tag_end;
diff --git a/gtk/gtkfontchooserdialog.c b/gtk/gtkfontchooserdialog.c
index f3cb5e11cb..232031ead4 100644
--- a/gtk/gtkfontchooserdialog.c
+++ b/gtk/gtkfontchooserdialog.c
@@ -79,7 +79,7 @@ struct _GtkFontChooserDialogPrivate
  * and “cancel_button”.
  */
 
-static void     gtk_font_chooser_dialog_buildable_interface_init     (GtkBuildableIface *iface);
+static void     gtk_font_chooser_dialog_buildable_interface_init     (GtkBuildableInterface *iface);
 static GObject *gtk_font_chooser_dialog_buildable_get_internal_child (GtkBuildable *buildable,
                                                                       GtkBuilder   *builder,
                                                                       const gchar  *childname);
@@ -91,7 +91,7 @@ G_DEFINE_TYPE_WITH_CODE (GtkFontChooserDialog, gtk_font_chooser_dialog, GTK_TYPE
                          G_IMPLEMENT_INTERFACE (GTK_TYPE_BUILDABLE,
                                                 gtk_font_chooser_dialog_buildable_interface_init))
 
-static GtkBuildableIface *parent_buildable_iface;
+static GtkBuildableInterface *parent_buildable_iface;
 
 static void
 gtk_font_chooser_dialog_set_property (GObject      *object,
@@ -292,7 +292,7 @@ gtk_font_chooser_dialog_new (const gchar *title,
 }
 
 static void
-gtk_font_chooser_dialog_buildable_interface_init (GtkBuildableIface *iface)
+gtk_font_chooser_dialog_buildable_interface_init (GtkBuildableInterface *iface)
 {
   parent_buildable_iface = g_type_interface_peek_parent (iface);
   iface->get_internal_child = gtk_font_chooser_dialog_buildable_get_internal_child;
diff --git a/gtk/gtkframe.c b/gtk/gtkframe.c
index 961c4a23b3..7670df7024 100644
--- a/gtk/gtkframe.c
+++ b/gtk/gtkframe.c
@@ -130,7 +130,7 @@ static void gtk_frame_real_compute_child_allocation (GtkFrame      *frame,
                                                     GtkAllocation *child_allocation);
 
 /* GtkBuildable */
-static void gtk_frame_buildable_init                (GtkBuildableIface *iface);
+static void gtk_frame_buildable_init                (GtkBuildableInterface *iface);
 static void gtk_frame_buildable_add_child           (GtkBuildable *buildable,
                                                     GtkBuilder   *builder,
                                                     GObject      *child,
@@ -206,10 +206,10 @@ gtk_frame_class_init (GtkFrameClass *class)
   gtk_widget_class_set_css_name (widget_class, I_("frame"));
 }
 
-static GtkBuildableIface *parent_buildable_iface;
+static GtkBuildableInterface *parent_buildable_iface;
 
 static void
-gtk_frame_buildable_init (GtkBuildableIface *iface)
+gtk_frame_buildable_init (GtkBuildableInterface *iface)
 {
   parent_buildable_iface = g_type_interface_peek_parent (iface);
 
diff --git a/gtk/gtkheaderbar.c b/gtk/gtkheaderbar.c
index eb5bca55a4..ecd4b937f1 100644
--- a/gtk/gtkheaderbar.c
+++ b/gtk/gtkheaderbar.c
@@ -151,7 +151,7 @@ enum {
 
 static GParamSpec *header_bar_props[LAST_PROP] = { NULL, };
 
-static void gtk_header_bar_buildable_init (GtkBuildableIface *iface);
+static void gtk_header_bar_buildable_init (GtkBuildableInterface *iface);
 
 G_DEFINE_TYPE_WITH_CODE (GtkHeaderBar, gtk_header_bar, GTK_TYPE_CONTAINER,
                          G_ADD_PRIVATE (GtkHeaderBar)
@@ -1244,7 +1244,7 @@ gtk_header_bar_init (GtkHeaderBar *bar)
   construct_label_box (bar);
 }
 
-static GtkBuildableIface *parent_buildable_iface;
+static GtkBuildableInterface *parent_buildable_iface;
 
 static void
 gtk_header_bar_buildable_add_child (GtkBuildable *buildable,
@@ -1263,7 +1263,7 @@ gtk_header_bar_buildable_add_child (GtkBuildable *buildable,
 }
 
 static void
-gtk_header_bar_buildable_init (GtkBuildableIface *iface)
+gtk_header_bar_buildable_init (GtkBuildableInterface *iface)
 {
   parent_buildable_iface = g_type_interface_peek_parent (iface);
 
diff --git a/gtk/gtkiconview.c b/gtk/gtkiconview.c
index f3bb6ead98..6603c62373 100644
--- a/gtk/gtkiconview.c
+++ b/gtk/gtkiconview.c
@@ -308,8 +308,8 @@ static gboolean gtk_icon_view_maybe_begin_drag   (GtkIconView      *icon_view,
 static void     remove_scroll_timeout            (GtkIconView *icon_view);
 
 /* GtkBuildable */
-static GtkBuildableIface *parent_buildable_iface;
-static void     gtk_icon_view_buildable_init             (GtkBuildableIface  *iface);
+static GtkBuildableInterface *parent_buildable_iface;
+static void     gtk_icon_view_buildable_init             (GtkBuildableInterface  *iface);
 static gboolean gtk_icon_view_buildable_custom_tag_start (GtkBuildable       *buildable,
                                                           GtkBuilder         *builder,
                                                           GObject            *child,
@@ -906,7 +906,7 @@ gtk_icon_view_buildable_add_child (GtkBuildable *buildable,
 }
 
 static void
-gtk_icon_view_buildable_init (GtkBuildableIface *iface)
+gtk_icon_view_buildable_init (GtkBuildableInterface *iface)
 {
   parent_buildable_iface = g_type_interface_peek_parent (iface);
   iface->add_child = gtk_icon_view_buildable_add_child;
diff --git a/gtk/gtkinfobar.c b/gtk/gtkinfobar.c
index 96377336ca..19d84e9312 100644
--- a/gtk/gtkinfobar.c
+++ b/gtk/gtkinfobar.c
@@ -189,7 +189,7 @@ static void     gtk_info_bar_get_property (GObject        *object,
                                            guint           prop_id,
                                            GValue         *value,
                                            GParamSpec     *pspec);
-static void     gtk_info_bar_buildable_interface_init   (GtkBuildableIface  *iface);
+static void     gtk_info_bar_buildable_interface_init   (GtkBuildableInterface  *iface);
 static gboolean gtk_info_bar_buildable_custom_tag_start (GtkBuildable       *buildable,
                                                          GtkBuilder         *builder,
                                                          GObject            *child,
@@ -521,10 +521,10 @@ gtk_info_bar_init (GtkInfoBar *info_bar)
   gtk_widget_add_controller (widget, GTK_EVENT_CONTROLLER (gesture));
 }
 
-static GtkBuildableIface *parent_buildable_iface;
+static GtkBuildableInterface *parent_buildable_iface;
 
 static void
-gtk_info_bar_buildable_interface_init (GtkBuildableIface *iface)
+gtk_info_bar_buildable_interface_init (GtkBuildableInterface *iface)
 {
   parent_buildable_iface = g_type_interface_peek_parent (iface);
 
diff --git a/gtk/gtklabel.c b/gtk/gtklabel.c
index 0b7b884685..80b5877bef 100644
--- a/gtk/gtklabel.c
+++ b/gtk/gtklabel.c
@@ -504,7 +504,7 @@ static gboolean gtk_label_mnemonic_activate (GtkWidget         *widget,
                                             gboolean           group_cycling);
 static void     gtk_label_setup_mnemonic    (GtkLabel          *label);
 
-static void     gtk_label_buildable_interface_init   (GtkBuildableIface  *iface);
+static void     gtk_label_buildable_interface_init   (GtkBuildableInterface  *iface);
 static gboolean gtk_label_buildable_custom_tag_start (GtkBuildable       *buildable,
                                                       GtkBuilder         *builder,
                                                       GObject            *child,
@@ -599,7 +599,7 @@ static void     gtk_label_measure (GtkWidget     *widget,
 
 
 
-static GtkBuildableIface *buildable_parent_iface = NULL;
+static GtkBuildableInterface *buildable_parent_iface = NULL;
 
 G_DEFINE_TYPE_WITH_CODE (GtkLabel, gtk_label, GTK_TYPE_WIDGET,
                          G_ADD_PRIVATE (GtkLabel)
@@ -1352,7 +1352,7 @@ gtk_label_init (GtkLabel *label)
 
 
 static void
-gtk_label_buildable_interface_init (GtkBuildableIface *iface)
+gtk_label_buildable_interface_init (GtkBuildableInterface *iface)
 {
   buildable_parent_iface = g_type_interface_peek_parent (iface);
 
diff --git a/gtk/gtklevelbar.c b/gtk/gtklevelbar.c
index c34fcc5364..3bd056ab6f 100644
--- a/gtk/gtklevelbar.c
+++ b/gtk/gtklevelbar.c
@@ -197,7 +197,7 @@ struct _GtkLevelBarClass {
 static void gtk_level_bar_set_value_internal (GtkLevelBar *self,
                                               gdouble      value);
 
-static void gtk_level_bar_buildable_init (GtkBuildableIface *iface);
+static void gtk_level_bar_buildable_init (GtkBuildableInterface *iface);
 
 G_DEFINE_TYPE_WITH_CODE (GtkLevelBar, gtk_level_bar, GTK_TYPE_WIDGET,
                          G_IMPLEMENT_INTERFACE (GTK_TYPE_ORIENTABLE, NULL)
@@ -785,7 +785,7 @@ gtk_level_bar_buildable_custom_finished (GtkBuildable *buildable,
 }
 
 static void
-gtk_level_bar_buildable_init (GtkBuildableIface *iface)
+gtk_level_bar_buildable_init (GtkBuildableInterface *iface)
 {
   iface->custom_tag_start = gtk_level_bar_buildable_custom_tag_start;
   iface->custom_finished = gtk_level_bar_buildable_custom_finished;
diff --git a/gtk/gtklistbox.c b/gtk/gtklistbox.c
index def3c27e05..fa85e064ad 100644
--- a/gtk/gtklistbox.c
+++ b/gtk/gtklistbox.c
@@ -206,9 +206,9 @@ enum {
 
 #define ROW_PRIV(row) ((GtkListBoxRowPrivate*)gtk_list_box_row_get_instance_private ((GtkListBoxRow*)(row)))
 
-static GtkBuildableIface *parent_buildable_iface;
+static GtkBuildableInterface *parent_buildable_iface;
 
-static void     gtk_list_box_buildable_interface_init   (GtkBuildableIface *iface);
+static void     gtk_list_box_buildable_interface_init   (GtkBuildableInterface *iface);
 
 static void     gtk_list_box_row_actionable_iface_init  (GtkActionableInterface *iface);
 
@@ -3461,7 +3461,7 @@ gtk_list_box_buildable_add_child (GtkBuildable *buildable,
 }
 
 static void
-gtk_list_box_buildable_interface_init (GtkBuildableIface *iface)
+gtk_list_box_buildable_interface_init (GtkBuildableInterface *iface)
 {
   parent_buildable_iface = g_type_interface_peek_parent (iface);
 
diff --git a/gtk/gtkliststore.c b/gtk/gtkliststore.c
index 8c488fabed..dca4d09f6f 100644
--- a/gtk/gtkliststore.c
+++ b/gtk/gtkliststore.c
@@ -199,7 +199,7 @@ static void         gtk_list_store_tree_model_init (GtkTreeModelIface *iface);
 static void         gtk_list_store_drag_source_init(GtkTreeDragSourceIface *iface);
 static void         gtk_list_store_drag_dest_init  (GtkTreeDragDestIface   *iface);
 static void         gtk_list_store_sortable_init   (GtkTreeSortableIface   *iface);
-static void         gtk_list_store_buildable_init  (GtkBuildableIface      *iface);
+static void         gtk_list_store_buildable_init  (GtkBuildableInterface  *iface);
 static void         gtk_list_store_finalize        (GObject           *object);
 static GtkTreeModelFlags gtk_list_store_get_flags  (GtkTreeModel      *tree_model);
 static gint         gtk_list_store_get_n_columns   (GtkTreeModel      *tree_model);
@@ -363,7 +363,7 @@ gtk_list_store_sortable_init (GtkTreeSortableIface *iface)
 }
 
 void
-gtk_list_store_buildable_init (GtkBuildableIface *iface)
+gtk_list_store_buildable_init (GtkBuildableInterface *iface)
 {
   iface->custom_tag_start = gtk_list_store_buildable_custom_tag_start;
   iface->custom_tag_end = gtk_list_store_buildable_custom_tag_end;
diff --git a/gtk/gtknotebook.c b/gtk/gtknotebook.c
index 3dd45e6535..993a9aeeea 100644
--- a/gtk/gtknotebook.c
+++ b/gtk/gtknotebook.c
@@ -903,7 +903,7 @@ static void do_detach_tab  (GtkNotebook *from,
                             GtkWidget   *child);
 
 /* GtkBuildable */
-static void gtk_notebook_buildable_init           (GtkBuildableIface *iface);
+static void gtk_notebook_buildable_init           (GtkBuildableInterface *iface);
 static void gtk_notebook_buildable_add_child      (GtkBuildable *buildable,
                                                    GtkBuilder   *builder,
                                                    GObject      *child,
@@ -1454,10 +1454,10 @@ gtk_notebook_init (GtkNotebook *notebook)
   gtk_orientable_set_orientation (GTK_ORIENTABLE (layout), GTK_ORIENTATION_VERTICAL);
 }
 
-static GtkBuildableIface *parent_buildable_iface;
+static GtkBuildableInterface *parent_buildable_iface;
 
 static void
-gtk_notebook_buildable_init (GtkBuildableIface *iface)
+gtk_notebook_buildable_init (GtkBuildableInterface *iface)
 {
   parent_buildable_iface = g_type_interface_peek_parent (iface);
 
diff --git a/gtk/gtkoverlay.c b/gtk/gtkoverlay.c
index f23982221e..dd5d578522 100644
--- a/gtk/gtkoverlay.c
+++ b/gtk/gtkoverlay.c
@@ -73,7 +73,7 @@ enum {
 
 static guint signals[LAST_SIGNAL] = { 0 };
 
-static void gtk_overlay_buildable_init (GtkBuildableIface *iface);
+static void gtk_overlay_buildable_init (GtkBuildableInterface *iface);
 
 typedef struct _GtkOverlayClass    GtkOverlayClass;
 
@@ -336,7 +336,7 @@ gtk_overlay_init (GtkOverlay *overlay)
   priv->layout = gtk_widget_get_layout_manager (GTK_WIDGET (overlay));
 }
 
-static GtkBuildableIface *parent_buildable_iface;
+static GtkBuildableInterface *parent_buildable_iface;
 
 static void
 gtk_overlay_buildable_add_child (GtkBuildable *buildable,
@@ -364,7 +364,7 @@ gtk_overlay_buildable_add_child (GtkBuildable *buildable,
 }
 
 static void
-gtk_overlay_buildable_init (GtkBuildableIface *iface)
+gtk_overlay_buildable_init (GtkBuildableInterface *iface)
 {
   parent_buildable_iface = g_type_interface_peek_parent (iface);
 
diff --git a/gtk/gtkprintunixdialog.c b/gtk/gtkprintunixdialog.c
index aae3b0d4b4..0ba7d10419 100644
--- a/gtk/gtkprintunixdialog.c
+++ b/gtk/gtkprintunixdialog.c
@@ -214,7 +214,7 @@ static gboolean printer_compare                    (GtkTreeModel       *model,
                                                     gpointer            search_data);
 
 /* GtkBuildable */
-static void gtk_print_unix_dialog_buildable_init                    (GtkBuildableIface *iface);
+static void gtk_print_unix_dialog_buildable_init                    (GtkBuildableInterface *iface);
 static GObject *gtk_print_unix_dialog_buildable_get_internal_child  (GtkBuildable *buildable,
                                                                      GtkBuilder   *builder,
                                                                      const gchar  *childname);
@@ -388,7 +388,7 @@ G_DEFINE_TYPE_WITH_CODE (GtkPrintUnixDialog, gtk_print_unix_dialog, GTK_TYPE_DIA
                          G_IMPLEMENT_INTERFACE (GTK_TYPE_BUILDABLE,
                                                 gtk_print_unix_dialog_buildable_init))
 
-static GtkBuildableIface *parent_buildable_iface;
+static GtkBuildableInterface *parent_buildable_iface;
 
 static gboolean
 is_default_printer (GtkPrintUnixDialog *dialog,
@@ -928,7 +928,7 @@ printer_removed_cb (GtkPrintBackend    *backend,
 }
 
 static void
-gtk_print_unix_dialog_buildable_init (GtkBuildableIface *iface)
+gtk_print_unix_dialog_buildable_init (GtkBuildableInterface *iface)
 {
   parent_buildable_iface = g_type_interface_peek_parent (iface);
 
diff --git a/gtk/gtkscale.c b/gtk/gtkscale.c
index 9583c3ea9c..c2a209aef1 100644
--- a/gtk/gtkscale.c
+++ b/gtk/gtkscale.c
@@ -201,7 +201,7 @@ static void     gtk_scale_snapshot                (GtkWidget      *widget,
 static void     gtk_scale_real_get_layout_offsets (GtkScale       *scale,
                                                    gint           *x,
                                                    gint           *y);
-static void     gtk_scale_buildable_interface_init   (GtkBuildableIface  *iface);
+static void     gtk_scale_buildable_interface_init   (GtkBuildableInterface  *iface);
 static gboolean gtk_scale_buildable_custom_tag_start (GtkBuildable       *buildable,
                                                       GtkBuilder         *builder,
                                                       GObject            *child,
@@ -1804,10 +1804,10 @@ gtk_scale_add_mark (GtkScale        *scale,
   gtk_widget_queue_resize (widget);
 }
 
-static GtkBuildableIface *parent_buildable_iface;
+static GtkBuildableInterface *parent_buildable_iface;
 
 static void
-gtk_scale_buildable_interface_init (GtkBuildableIface *iface)
+gtk_scale_buildable_interface_init (GtkBuildableInterface *iface)
 {
   parent_buildable_iface = g_type_interface_peek_parent (iface);
   iface->custom_tag_start = gtk_scale_buildable_custom_tag_start;
diff --git a/gtk/gtkshortcutcontroller.c b/gtk/gtkshortcutcontroller.c
index 8fa081f977..41d765e5bb 100644
--- a/gtk/gtkshortcutcontroller.c
+++ b/gtk/gtkshortcutcontroller.c
@@ -159,7 +159,7 @@ gtk_shortcut_controller_buildable_add_child (GtkBuildable  *buildable,
 }
 
 static void
-gtk_shortcut_controller_buildable_init (GtkBuildableIface *iface)
+gtk_shortcut_controller_buildable_init (GtkBuildableInterface *iface)
 {
   iface->add_child = gtk_shortcut_controller_buildable_add_child;
 }
diff --git a/gtk/gtksizegroup.c b/gtk/gtksizegroup.c
index 2be53f5214..ef732935dc 100644
--- a/gtk/gtksizegroup.c
+++ b/gtk/gtksizegroup.c
@@ -132,7 +132,7 @@ static void gtk_size_group_get_property (GObject      *object,
                                         GParamSpec   *pspec);
 
 /* GtkBuildable */
-static void     gtk_size_group_buildable_init             (GtkBuildableIface  *iface);
+static void     gtk_size_group_buildable_init             (GtkBuildableInterface *iface);
 static gboolean gtk_size_group_buildable_custom_tag_start (GtkBuildable       *buildable,
                                                            GtkBuilder         *builder,
                                                            GObject            *child,
@@ -244,7 +244,7 @@ gtk_size_group_init (GtkSizeGroup *size_group)
 }
 
 static void
-gtk_size_group_buildable_init (GtkBuildableIface *iface)
+gtk_size_group_buildable_init (GtkBuildableInterface *iface)
 {
   iface->custom_tag_start = gtk_size_group_buildable_custom_tag_start;
   iface->custom_finished = gtk_size_group_buildable_custom_finished;
diff --git a/gtk/gtkstack.c b/gtk/gtkstack.c
index 887c9cf6c9..10a3a5f5fb 100644
--- a/gtk/gtkstack.c
+++ b/gtk/gtkstack.c
@@ -156,7 +156,7 @@ typedef struct {
 
 } GtkStackPrivate;
 
-static void gtk_stack_buildable_interface_init (GtkBuildableIface *iface);
+static void gtk_stack_buildable_interface_init (GtkBuildableInterface *iface);
 
 G_DEFINE_TYPE_WITH_CODE (GtkStack, gtk_stack, GTK_TYPE_CONTAINER,
                          G_ADD_PRIVATE (GtkStack)
@@ -587,7 +587,7 @@ gtk_stack_buildable_add_child (GtkBuildable *buildable,
 }
 
 static void
-gtk_stack_buildable_interface_init (GtkBuildableIface *iface)
+gtk_stack_buildable_interface_init (GtkBuildableInterface *iface)
 {
   iface->add_child = gtk_stack_buildable_add_child;
 }
diff --git a/gtk/gtktexttagtable.c b/gtk/gtktexttagtable.c
index c28621edd6..7040a06b6f 100644
--- a/gtk/gtktexttagtable.c
+++ b/gtk/gtktexttagtable.c
@@ -101,7 +101,7 @@ enum {
 
 static void gtk_text_tag_table_finalize                 (GObject             *object);
 
-static void gtk_text_tag_table_buildable_interface_init (GtkBuildableIface   *iface);
+static void gtk_text_tag_table_buildable_interface_init (GtkBuildableInterface *iface);
 static void gtk_text_tag_table_buildable_add_child      (GtkBuildable        *buildable,
                                                         GtkBuilder          *builder,
                                                         GObject             *child,
@@ -251,7 +251,7 @@ gtk_text_tag_table_finalize (GObject *object)
 }
 
 static void
-gtk_text_tag_table_buildable_interface_init (GtkBuildableIface   *iface)
+gtk_text_tag_table_buildable_interface_init (GtkBuildableInterface *iface)
 {
   iface->add_child = gtk_text_tag_table_buildable_add_child;
 }
diff --git a/gtk/gtktreestore.c b/gtk/gtktreestore.c
index df64028a3d..3eab8fe83a 100644
--- a/gtk/gtktreestore.c
+++ b/gtk/gtktreestore.c
@@ -86,7 +86,7 @@ static void         gtk_tree_store_tree_model_init (GtkTreeModelIface *iface);
 static void         gtk_tree_store_drag_source_init(GtkTreeDragSourceIface *iface);
 static void         gtk_tree_store_drag_dest_init  (GtkTreeDragDestIface   *iface);
 static void         gtk_tree_store_sortable_init   (GtkTreeSortableIface   *iface);
-static void         gtk_tree_store_buildable_init  (GtkBuildableIface      *iface);
+static void         gtk_tree_store_buildable_init  (GtkBuildableInterface  *iface);
 static void         gtk_tree_store_finalize        (GObject           *object);
 static GtkTreeModelFlags gtk_tree_store_get_flags  (GtkTreeModel      *tree_model);
 static gint         gtk_tree_store_get_n_columns   (GtkTreeModel      *tree_model);
@@ -273,7 +273,7 @@ gtk_tree_store_sortable_init (GtkTreeSortableIface *iface)
 }
 
 void
-gtk_tree_store_buildable_init (GtkBuildableIface *iface)
+gtk_tree_store_buildable_init (GtkBuildableInterface *iface)
 {
   iface->custom_tag_start = gtk_tree_store_buildable_custom_tag_start;
   iface->custom_finished = gtk_tree_store_buildable_custom_finished;
diff --git a/gtk/gtktreeview.c b/gtk/gtktreeview.c
index 548034619c..20c414e959 100644
--- a/gtk/gtktreeview.c
+++ b/gtk/gtktreeview.c
@@ -915,7 +915,7 @@ static void     gtk_tree_view_buildable_add_child          (GtkBuildable      *t
 static GObject *gtk_tree_view_buildable_get_internal_child (GtkBuildable      *buildable,
                                                            GtkBuilder        *builder,
                                                            const gchar       *childname);
-static void     gtk_tree_view_buildable_init               (GtkBuildableIface *iface);
+static void     gtk_tree_view_buildable_init               (GtkBuildableInterface *iface);
 
 /* GtkScrollable */
 static void     gtk_tree_view_scrollable_init              (GtkScrollableInterface *iface);
@@ -2043,10 +2043,10 @@ gtk_tree_view_finalize (GObject *object)
 }
 
 
-static GtkBuildableIface *parent_buildable_iface;
+static GtkBuildableInterface *parent_buildable_iface;
 
 static void
-gtk_tree_view_buildable_init (GtkBuildableIface *iface)
+gtk_tree_view_buildable_init (GtkBuildableInterface *iface)
 {
   parent_buildable_iface = g_type_interface_peek_parent (iface);
   iface->add_child = gtk_tree_view_buildable_add_child;
diff --git a/gtk/gtktreeviewcolumn.c b/gtk/gtktreeviewcolumn.c
index d5152fdecb..0ad913a00e 100644
--- a/gtk/gtktreeviewcolumn.c
+++ b/gtk/gtktreeviewcolumn.c
@@ -133,7 +133,7 @@ static void gtk_tree_view_column_set_attributesv               (GtkTreeViewColum
                                                                va_list                  args);
 
 /* GtkBuildable implementation */
-static void gtk_tree_view_column_buildable_init                 (GtkBuildableIface     *iface);
+static void gtk_tree_view_column_buildable_init                 (GtkBuildableInterface     *iface);
 
 typedef struct _GtkTreeViewColumnClass   GtkTreeViewColumnClass;
 typedef struct _GtkTreeViewColumnPrivate GtkTreeViewColumnPrivate;
@@ -440,7 +440,7 @@ gtk_tree_view_column_custom_tag_end (GtkBuildable *buildable,
 }
 
 static void
-gtk_tree_view_column_buildable_init (GtkBuildableIface *iface)
+gtk_tree_view_column_buildable_init (GtkBuildableInterface *iface)
 {
   iface->add_child = _gtk_cell_layout_buildable_add_child;
   iface->custom_tag_start = _gtk_cell_layout_buildable_custom_tag_start;
diff --git a/gtk/gtkwindow.c b/gtk/gtkwindow.c
index d7a62f52ab..0cc296dc3a 100644
--- a/gtk/gtkwindow.c
+++ b/gtk/gtkwindow.c
@@ -491,7 +491,7 @@ static gboolean     disable_startup_notification = FALSE;
 
 static GQuark       quark_gtk_window_icon_info = 0;
 
-static GtkBuildableIface *parent_buildable_iface;
+static GtkBuildableInterface *parent_buildable_iface;
 
 static void gtk_window_set_property (GObject         *object,
                                     guint            prop_id,
@@ -503,7 +503,7 @@ static void gtk_window_get_property (GObject         *object,
                                     GParamSpec      *pspec);
 
 /* GtkBuildable */
-static void     gtk_window_buildable_interface_init         (GtkBuildableIface  *iface);
+static void     gtk_window_buildable_interface_init         (GtkBuildableInterface  *iface);
 static void     gtk_window_buildable_add_child              (GtkBuildable       *buildable,
                                                              GtkBuilder         *builder,
                                                              GObject            *child,
@@ -1951,7 +1951,7 @@ gtk_window_get_property (GObject      *object,
 }
 
 static void
-gtk_window_buildable_interface_init (GtkBuildableIface *iface)
+gtk_window_buildable_interface_init (GtkBuildableInterface *iface)
 {
   parent_buildable_iface = g_type_interface_peek_parent (iface);
   iface->set_buildable_property = gtk_window_buildable_set_buildable_property;


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/gtk/gtkbuildable.h b/gtk/gtkbuildable.h
index 7808f0445d..ba7e18f355 100644
--- a/gtk/gtkbuildable.h
+++ b/gtk/gtkbuildable.h
@@ -27,14 +27,8 @@
 
 G_BEGIN_DECLS
 
-#define GTK_TYPE_BUILDABLE            (gtk_buildable_get_type ())
-#define GTK_BUILDABLE(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTK_TYPE_BUILDABLE, GtkBuildable))
-#define GTK_BUILDABLE_CLASS(obj)      (G_TYPE_CHECK_CLASS_CAST ((obj), GTK_TYPE_BUILDABLE, 
GtkBuildableIface))
-#define GTK_IS_BUILDABLE(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTK_TYPE_BUILDABLE))
-#define GTK_BUILDABLE_GET_IFACE(obj)  (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GTK_TYPE_BUILDABLE, 
GtkBuildableIface))
-
-typedef struct _GtkBuildable      GtkBuildable; /* Dummy typedef */
-typedef struct _GtkBuildableIface GtkBuildableIface;
+#define GTK_TYPE_BUILDABLE (gtk_buildable_get_type ())
+G_DECLARE_INTERFACE (GtkBuildable, gtk_buildable, GTK, BUILDABLE, GObject)
 
 typedef struct _GtkBuildableParseContext      GtkBuildableParseContext;
 typedef struct _GtkBuildableParser GtkBuildableParser;
@@ -74,7 +68,7 @@ struct _GtkBuildableParser
 };
 
 /**
- * GtkBuildableIface:
+ * GtkBuildableInterface:
  * @g_iface: the parent class
  * @set_name: Stores the name attribute given in the GtkBuilder UI definition.
  *  #GtkWidget stores the name as object data. Implement this method if your
@@ -117,11 +111,11 @@ struct _GtkBuildableParser
  *  Implement this if the buildable has internal children that may
  *  need to be accessed from a UI definition.
  *
  * The #GtkBuildableIface interface contains method that are
  * necessary to allow #GtkBuilder to construct an object from
  * a #GtkBuilder UI definition.
  */
-struct _GtkBuildableIface
+struct _GtkBuildableInterface
 {
   GTypeInterface g_iface;
 
@@ -165,9 +159,6 @@ struct _GtkBuildableIface
 };
 
 
-GDK_AVAILABLE_IN_ALL
-GType     gtk_buildable_get_type               (void) G_GNUC_CONST;
-
 GDK_AVAILABLE_IN_ALL
 void      gtk_buildable_set_name               (GtkBuildable        *buildable,
                                                const gchar         *name);
@@ -117,11 +111,11 @@ struct _GtkBuildableParser
  *  need to be accessed from a UI definition.
  *
- * The #GtkBuildableIface interface contains method that are
+ * The #GtkBuildableInterface interface contains methods that are
  * necessary to allow #GtkBuilder to construct an object from
  * a #GtkBuilder UI definition.
diff --git a/gtk/gtkwidget.c b/gtk/gtkwidget.c
index a276b3369b..4d99a71f60 100644
--- a/gtk/gtkwidget.c
+++ b/gtk/gtkwidget.c
@@ -632,7 +632,7 @@ static AtkObject*   gtk_widget_real_get_accessible          (GtkWidget        *widget);
 static void            gtk_widget_accessible_interface_init    (AtkImplementorIface *iface);
 static AtkObject*      gtk_widget_ref_accessible               (AtkImplementor *implementor);
 
-static void             gtk_widget_buildable_interface_init     (GtkBuildableIface  *iface);
+static void             gtk_widget_buildable_interface_init     (GtkBuildableInterface  *iface);
 static void             gtk_widget_buildable_set_name           (GtkBuildable       *buildable,
                                                                  const gchar        *name);
 static const gchar *    gtk_widget_buildable_get_name           (GtkBuildable       *buildable);
@@ -8467,7 +8467,7 @@ gtk_widget_buildable_add_child (GtkBuildable  *buildable,
 }
 
 static void
-gtk_widget_buildable_interface_init (GtkBuildableIface *iface)
+gtk_widget_buildable_interface_init (GtkBuildableInterface *iface)
 {
   quark_builder_atk_relations = g_quark_from_static_string ("gtk-builder-atk-relations");
   quark_builder_set_name = g_quark_from_static_string ("gtk-builder-set-name");
@@ -11163,7 +11163,7 @@ gtk_widget_class_set_template_scope (GtkWidgetClass  *widget_class,
  * pointer the first time your classes #GObjectClass.dispose() runs, or alternatively in
  * #GtkWidgetClass.destroy().
  *
  * If @internal_child is specified, #GtkBuildableIface.get_internal_child() will be automatically
  * implemented by the #GtkWidget class so there is no need to implement it manually.
  *
  * The wrapper macros gtk_widget_class_bind_template_child(), 
@@ -11163,7 +11163,7 @@ gtk_widget_class_set_template_scope (GtkWidgetClass  *widget_class,
  * #GtkWidgetClass.destroy().
  *
- * If @internal_child is specified, #GtkBuildableIface.get_internal_child() will be automatically
+ * If @internal_child is specified, #GtkBuildableInterface.get_internal_child() will be automatically
  * implemented by the #GtkWidget class so there is no need to implement it manually.
  *
gtk_widget_class_bind_template_child_internal(),